@@ -6,6 +6,7 @@ import os
 import re
 
 from sqlalchemy import exc as sqla_exc
+from sqlalchemy import text
 
 from alembic import command
 from alembic import config
@@ -100,8 +101,14 @@ finally:
         if env_token:
             assert_lines.insert(0, "environment included OK")
 
+        actual = (
+            buf.getvalue()
+            .decode("ascii", "replace")
+            .replace(os.linesep, "\n")
+            .strip()
+        )
         eq_(
-            buf.getvalue().decode("ascii", "replace").strip(),
+            actual,
             "\n".join(assert_lines)
             .encode("ascii", "replace")
             .decode("ascii")
@@ -365,11 +372,14 @@ finally:
         r2 = command.revision(self.cfg)
         db = _sqlite_file_db()
         command.upgrade(self.cfg, "head")
-        assert_raises(
-            sqla_exc.IntegrityError,
-            db.execute,
-            "insert into alembic_version values ('%s')" % r2.revision,
-        )
+        with db.connect() as conn:
+            assert_raises(
+                sqla_exc.IntegrityError,
+                conn.execute,
+                text(
+                    "insert into alembic_version values ('%s')" % r2.revision
+                ),
+            )
 
     def test_err_correctly_raised_on_dupe_rows_no_pk(self):
         self._env_fixture(version_table_pk=False)
@@ -377,7 +387,10 @@ finally:
         r2 = command.revision(self.cfg)
         db = _sqlite_file_db()
         command.upgrade(self.cfg, "head")
-        db.execute("insert into alembic_version values ('%s')" % r2.revision)
+        with db.connect() as conn:
+            conn.execute(
+                text("insert into alembic_version values ('%s')" % r2.revision)
+            )
         assert_raises_message(
             util.CommandError,
             "Online migration expected to match one row when "
@@ -658,7 +671,7 @@ class StampMultipleHeadsTest(TestBase, _StampTest):
         eng = _sqlite_file_db()
         with eng.connect() as conn:
             result = conn.execute(
-                "update alembic_version set version_num='fake'"
+                text("update alembic_version set version_num='fake'")
             )
             eq_(result.rowcount, 1)
 
@@ -837,31 +850,39 @@ down_revision = '%s'
 
     def test_stamp_creates_table(self):
         command.stamp(self.cfg, "head")
-        eq_(
-            self.bind.scalar("select version_num from alembic_version"), self.b
-        )
+        with self.bind.connect() as conn:
+            eq_(
+                conn.scalar(text("select version_num from alembic_version")),
+                self.b,
+            )
 
     def test_stamp_existing_upgrade(self):
         command.stamp(self.cfg, self.a)
         command.stamp(self.cfg, self.b)
-        eq_(
-            self.bind.scalar("select version_num from alembic_version"), self.b
-        )
+        with self.bind.connect() as conn:
+            eq_(
+                conn.scalar(text("select version_num from alembic_version")),
+                self.b,
+            )
 
     def test_stamp_existing_downgrade(self):
         command.stamp(self.cfg, self.b)
         command.stamp(self.cfg, self.a)
-        eq_(
-            self.bind.scalar("select version_num from alembic_version"), self.a
-        )
+        with self.bind.connect() as conn:
+            eq_(
+                conn.scalar(text("select version_num from alembic_version")),
+                self.a,
+            )
 
     def test_stamp_version_already_there(self):
         command.stamp(self.cfg, self.b)
         command.stamp(self.cfg, self.b)
 
-        eq_(
-            self.bind.scalar("select version_num from alembic_version"), self.b
-        )
+        with self.bind.connect() as conn:
+            eq_(
+                conn.scalar(text("select version_num from alembic_version")),
+                self.b,
+            )
 
 
 class EditTest(TestBase):
@@ -879,9 +900,9 @@ class EditTest(TestBase):
         command.stamp(self.cfg, "base")
 
     def test_edit_head(self):
-        expected_call_arg = "%s/scripts/versions/%s_revision_c.py" % (
-            EditTest.cfg.config_args["here"],
-            EditTest.c,
+        expected_call_arg = os.path.normpath(
+            "%s/scripts/versions/%s_revision_c.py"
+            % (EditTest.cfg.config_args["here"], EditTest.c)
         )
 
         with mock.patch("alembic.util.edit") as edit:
@@ -889,9 +910,9 @@ class EditTest(TestBase):
             edit.assert_called_with(expected_call_arg)
 
     def test_edit_b(self):
-        expected_call_arg = "%s/scripts/versions/%s_revision_b.py" % (
-            EditTest.cfg.config_args["here"],
-            EditTest.b,
+        expected_call_arg = os.path.normpath(
+            "%s/scripts/versions/%s_revision_b.py"
+            % (EditTest.cfg.config_args["here"], EditTest.b)
         )
 
         with mock.patch("alembic.util.edit") as edit:
@@ -928,9 +949,9 @@ class EditTest(TestBase):
         )
 
     def test_edit_current(self):
-        expected_call_arg = "%s/scripts/versions/%s_revision_b.py" % (
-            EditTest.cfg.config_args["here"],
-            EditTest.b,
+        expected_call_arg = os.path.normpath(
+            "%s/scripts/versions/%s_revision_b.py"
+            % (EditTest.cfg.config_args["here"], EditTest.b)
         )
 
         command.stamp(self.cfg, self.b)
@@ -1096,7 +1117,10 @@ class CommandLineTest(TestBase):
             "alembic.command.ScriptDirectory"
         ):
             command.init(self.cfg, directory="foobar")
-            eq_(makedirs.mock_calls, [mock.call("foobar/versions")])
+            eq_(
+                makedirs.mock_calls,
+                [mock.call(os.path.normpath("foobar/versions"))],
+            )
 
     def test_init_file_doesnt_exist(self):
         def access_(path, mode):
@@ -1113,7 +1137,10 @@ class CommandLineTest(TestBase):
             command.init(self.cfg, directory="foobar")
             eq_(
                 makedirs.mock_calls,
-                [mock.call("foobar"), mock.call("foobar/versions")],
+                [
+                    mock.call("foobar"),
+                    mock.call(os.path.normpath("foobar/versions")),
+                ],
             )
 
     def test_init_w_package(self):
